Package: DendSer
Version: 1.0.3
Date: 2026-02-03
Authors@R: c(person(given = c("Catherine", "B."),
                        family = "Hurley",
                        role = "aut"),
                 person(given = "Denise",
                        family = "Earle",
                        role = "aut"),
                 person(given = "Catherine",
                        family = "Hurley",
                        role = "cre",
                        email = "catherine.hurley@mu.ie"))
Title: Dendrogram Seriation: Ordering for Visualisation
Description: Re-arranges a dendrogram to optimize visualisation-based cost functions.
    The methods implemented here are described in "Advances in Dendrogram Seriation for Application 
    to Visualization", Journal of Computational and Graphical Statistics (2015) D. Earle and C.B. Hurley  <doi:10.1080/10618600.2013.874295>.
License: GPL-2
Encoding: UTF-8
RoxygenNote: 7.3.3
Imports: gclus, graphics, seriation, stats, utils
Suggests: HSAUR2, Iyer517, RColorBrewer, mvtnorm, scagnostics, knitr,
        rmarkdown
VignetteBuilder: knitr
NeedsCompilation: yes
Packaged: 2026-02-13 16:08:56 UTC; catherine
Author: Catherine B. Hurley [aut],
  Denise Earle [aut],
  Catherine Hurley [cre]
Maintainer: Catherine Hurley <catherine.hurley@mu.ie>
Repository: CRAN
Date/Publication: 2026-02-13 17:40:17 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-27 22:58:37 UTC; unix
Archs: DendSer.so.dSYM
