# Generated by roxygen2: do not edit by hand

S3method(dser,data.frame)
S3method(dser,dist)
S3method(dser,hclust)
S3method(dser,matrix)
export(DendSer)
export(costARc)
export(costBAR)
export(costED)
export(costLPL)
export(costLS)
export(costPL)
export(crit2cost)
export(dser)
export(plotAsColor)
importFrom(gclus,reorder.hclust)
importFrom(graphics,axis)
importFrom(graphics,box)
importFrom(graphics,image)
importFrom(seriation,criterion)
importFrom(seriation,get_criterion_method)
importFrom(seriation,get_order)
importFrom(seriation,list_criterion_methods)
importFrom(stats,as.dist)
importFrom(stats,dist)
importFrom(stats,hclust)
importFrom(utils,getFromNamespace)
importFrom(utils,modifyList)
useDynLib(DendSer, carct, cbar, clpl, cpl, .registration = TRUE)
